==> open-xchange-mobile-api-facade_1.0.1.orig.tar.bz2: open-xchange-mobile-api-facade-1.0.1/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/endpoints/ContactsEndpoint.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.endpoints;

import javax.annotation.security.PermitAll;
import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

import com.openexchange.mobile.api.facade.endpoints.responses.ContactsResponseBody;
import com.openexchange.mobile.api.facade.endpoints.responses.ctos.ContactCto;
import com.openexchange.mobile.api.facade.models.Contact;
import com.openexchange.mobile.api.facade.services.ContactsService;
import com.openexchange.mobile.api.facade.utils.ListUtil;
import com.openexchange.mobile.api.facade.utils.MapFunction;
import com.openexchange.mobile.api.facade.utils.RequestUtil;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import lombok.val;

@Path("/api-facade/v1/contacts")
@RequiredArgsConstructor
@PermitAll
@Slf4j
public class ContactsEndpoint {

    private final ContactsService contactsService;

    private static final MapFunction<Contact, ContactCto> contactMapFunction = new MapFunction<Contact, ContactCto>() {
        @Override
        public ContactCto map(Contact contact) {
            return new ContactCto(contact);
        }
    };

    @GET
    @Produces(MediaType.APPLICATION_JSON)
    public Response getAllContacts(@Context HttpServletRequest request) {
        log.info("Retrieving contacts");
        val sessionData = RequestUtil.getSessionData(request);
        val contacts = contactsService.getAllContacts(sessionData);
        val contactCtos = ListUtil.map(contacts, contactMapFunction);
        val responseBody = new ContactsResponseBody(contactCtos);
        return RequestUtil.jsonResponse(responseBody);
    }

}

==> open-xchange-mobile-api-facade_1.2.0.orig.tar.bz2: open-xchange-mobile-api-facade-1.2.0/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/endpoints/ContactsEndpoint.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.endpoints;

import javax.annotation.security.PermitAll;
import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

import com.openexchange.mobile.api.facade.endpoints.responses.ContactsResponseBody;
import com.openexchange.mobile.api.facade.endpoints.responses.ctos.ContactCto;
import com.openexchange.mobile.api.facade.models.Contact;
import com.openexchange.mobile.api.facade.services.ContactsService;
import com.openexchange.mobile.api.facade.utils.ListUtil;
import com.openexchange.mobile.api.facade.utils.MapFunction;
import com.openexchange.mobile.api.facade.utils.RequestUtil;

import lombok.RequiredArgsConstructor;
import lombok.val;
import lombok.extern.slf4j.Slf4j;

@Path("/api-facade/v1/contacts")
@RequiredArgsConstructor
@PermitAll
@Slf4j
public class ContactsEndpoint {

    private final ContactsService contactsService;

    private static final MapFunction<Contact, ContactCto> contactMapFunction = new MapFunction<Contact, ContactCto>() {
        @Override
        public ContactCto map(Contact contact) {
            return new ContactCto(contact);
        }
    };

    @GET
    @Produces(MediaType.APPLICATION_JSON)
    public Response getAllContacts(@Context HttpServletRequest request) {
        log.info("Retrieving contacts");
        val sessionData = RequestUtil.getSessionData(request);
        val contacts = contactsService.getAllContacts(sessionData);
        val contactCtos = ListUtil.map(contacts, contactMapFunction);
        val responseBody = new ContactsResponseBody(contactCtos);
        return RequestUtil.createCachableResponse(request, responseBody);
    }

}
